//
//  AudioRoomCallback-Player.h
//  zegoaudioroom
//
//  Copyright © 2017年 ZEGO. All rights reserved.
//

#ifndef AudioRoomCallback_Player_h
#define AudioRoomCallback_Player_h

#include "./AudioRoomDefines.h"

namespace ZEGO
{
    namespace AUDIOROOM
    {
        class IAudioLivePlayerCallback
        {
        public:
            /**
             播放状态更新
             
             @param stateCode 状态码
             @param pStreamInfo 流信息
             */
            virtual void OnPlayStateUpdate(int stateCode, const ZegoStreamInfo& pStreamInfo) = 0;
            
			/**
			观看质量更新

			@param pszStreamID 观看流 ID
			@param playQuality ZegoPlayQuality 对象，内部包含了各项质量数据
			*/
			virtual void OnPlayQualityUpdate(const char* pszStreamID, ZegoPlayQuality playQuality) {}

            /**
             远端麦克风状态通知
             
             @attention
             * 1. 仅拉 UDP 流有效；
             * 2. 当房间内其他流的麦克风状态发生改变，如其他用户调用了 EnableMic (true/false) 后，会收到该 API 回调通知。
             
             @param pStreamID 流 ID
             @param nStatus，参考 zego-api-defines.h 中 DeviceStatus 的定义
             @param nReason，参考 zego-api-defines.h 中 ZegoDeviceErrorReason 的定义
             */
            virtual void OnRemoteMicStatusUpdate(const char* pStreamID, int nStatus, int nReason) {};
            
            /**
             接收到远端音频的首帧通知
             
             @attention
             * 1. 当远端音频的首帧到达后，会收到该 API 回调通知。

             @param pStreamID 流 ID
             */
            virtual void OnRecvRemoteAudioFirstFrame(const char* pStreamID) {};

            virtual ~IAudioLivePlayerCallback() {}
        };
    }
}

#endif /* AudioRoomCallback_Player_h */
