#ifndef zego_api_auto_mix_stream_h
#define zego_api_auto_mix_stream_h
#include "./zego-api-auto-mix-stream-defines.h"

namespace ZEGO
{
    namespace AUTOMIXSTREAM
    {
        /**
         混流配置信息的回调接口
         */
        class IZegoAutoMixStreamCallback
        {
        public:
            /**
             调用开始自动混流的回调
             @param seq 调用序号, 和调用接口时返回的序号一一对应
             @param error 错误码
             */
            virtual void OnStartAutoMixStream(int seq, unsigned int error) = 0;
            /**
             调用结束自动混流的回调
             @param seq 调用序号, 和调用接口时返回的序号一一对应
             @param error 错误码
             */
            virtual void OnStopAutoMixStream(int seq, unsigned int error) = 0;
            
            virtual ~IZegoAutoMixStreamCallback() {}
        };

        /**
         自动混流中的发言者及其说话音量的回调通知接口
         */
        class IZegoSoundLevelInAutoMixedStreamCallback
        {
        public:
            /**
             自动混流中的发言者及其说话音量的回调通知
             
             @param volume_list 音浪信息列表
             @param list_size 音浪信息个数
             @note 此接口是高频率同步回调，每秒钟10次通知，不拉流没有通知；请勿在该回调中处理耗时任务。
             */
            virtual void OnSoundLevelInAutoMixedPlayStream(ZegoAutoMixStreamSoundLevel *volume_list, int list_size) = 0;

            virtual ~IZegoSoundLevelInAutoMixedStreamCallback() {}

        };
        
        
        /**
         设置自动混流的事件回调
         
         @param pCB 回调指针
         */
        ZEGOAVKIT_API bool SetAutoMixStreamCallback(IZegoAutoMixStreamCallback* pCB);

        /**
         设置自动混流中的发言者及其说话音量的回调通知
         
         @param pCB 回调指针
         */
        ZEGOAVKIT_API bool SetSoundLevelInAutoMixedStreamCallback(IZegoSoundLevelInAutoMixedStreamCallback* pCB);

        /**
         开始自动混流
         
         @param task_id 自动混流任务 ID
         @param room_id 房间 ID
         @param config 自动混流配置
         @return 返回值大于 0 表示成功, 其值为调用序号. -1 为失败
         */
        ZEGOAVKIT_API int StartAutoMixStream(const char* task_id, const char* room_id, const ZegoAutoMixStreamConfig config);

        /**
         停止自动混流

         @param task_id 自动混流任务 ID
         @param room_id 房间 ID
         @return 返回值大于 0 表示成功, 其值为调用序号. -1 为失败
         */
        ZEGOAVKIT_API int StopAutoMixStream(const char* task_id, const char* room_id);
       
        
    }
}
#endif
