#ifndef zego_api_sound_level_h
#define zego_api_sound_level_h

#include <zego-api-defines.h>

namespace ZEGO
{
    namespace SOUNDLEVEL
    {
    
        /**
         * 某条流的音浪信息
         */
        struct ZegoSoundLevelInfo
        {
            /**
             * 音浪信息，包含流 ID 及音量值
             */
            ZegoSoundLevelInfo()
            {
                szStreamID[0] = '\0';
                soundLevel = 0.0f;
                vad = 0;
            }
            
            /**
             * 此音浪信息的流 ID，当为采集音浪信息时，不必关心此值
             */
            char szStreamID[ZEGO_MAX_COMMON_LEN];
            /**
             * szStreamID 对应的流的音浪值，取值范围：[0.0, 100.0]
             */
            float soundLevel;
            /**
             * szStreamID 对应的流是否包含人声，0:表示噪声，1:表示人声，调用EnableVADMonitor(true)后此值才有效
             */
            int  vad;
        };
        
        class IZegoSoundLevelCallback
        {
        public:
            /**
             拉流音浪信息更新回调。回调频率由 SetSoundLevelMonitorCycle 指定，默认 200ms 回调一次

             @param pSoundLevelList 房间内所有流（非自己推的流）的音浪信息，是一个指向数组的指针，元素个数由 soundLevelCount 指定
             @param soundLevelCount 指明数组指针 pSoundLevelList 包含多少条音浪信息
             */
            virtual void OnSoundLevelUpdate(ZegoSoundLevelInfo *pSoundLevelList, unsigned int soundLevelCount) = 0;
            
            /**
             推流音浪信息更新回调。回调频率由 SetSoundLevelMonitorCycle 指定，默认 200ms 回调一次
             
             @param pCaptureSoundLevel 房间内采集的音浪信息（自己推的流）
             */
            virtual void OnCaptureSoundLevelUpdate(ZegoSoundLevelInfo *pCaptureSoundLevel) = 0;
            
            virtual ~ IZegoSoundLevelCallback() {}
        };

        /**
         设置获取音浪信息的回调对象。启动音浪监听后，通过此对象返回音浪信息
         
         @param pCB 实现 IZegoSoundLevelCallback 接口的对象实例
         @return true 成功；false 失败
         */
        ZEGOAVKIT_API bool SetSoundLevelCallback(IZegoSoundLevelCallback* pCB);
        
        /**
         设置音浪回调的监控周期
         
         @param timeInMS 时间周期，单位为毫秒，取值范围 [100, 3000]。默认 200 ms。
         @return true 成功；false 失败
         */
        ZEGOAVKIT_API bool SetSoundLevelMonitorCycle(unsigned int timeInMS);
        
        /**
         启动音浪监听
         
         @return true 成功，等待回调；false 失败
         @discussion StartSoundLevelMonitor 后一定要 StopSoundLevelMonitor
         */
        ZEGOAVKIT_API bool StartSoundLevelMonitor();
        
        /**
         停止音浪监听
         
         @return true 成功；false 失败
         */
        ZEGOAVKIT_API bool StopSoundLevelMonitor();

        /**
         设置音浪回调是否检测VAD，VAD算法有性能开销，建议按需设置
         
         @param enable true 开启；false 关闭。默认 关闭。
         @return true 成功；false 失败
         */
        ZEGOAVKIT_API bool EnableVADMonitor(bool enable);
        
    }
}

#endif /* zego_api_sound_level_h */
